pub struct HotCache { /* private fields */ }Expand description
In-memory hot cache for semantic query dedup.
Thin wrapper around totalreclaw_core::hotcache::HotCache<Vec<MemoryEntry>>.
Implementations
Sourceimpl HotCache
impl HotCache
Sourcepub fn new() -> Self
pub fn new() -> Self
Create an empty hot cache with default settings (30 entries, cosine >= 0.85).
Sourcepub fn lookup(&self, query_embedding: &[f32]) -> Option<Vec<MemoryEntry>>
pub fn lookup(&self, query_embedding: &[f32]) -> Option<Vec<MemoryEntry>>
Check if a semantically similar query has already been answered.
Returns cached results if a query with cosine >= 0.85 exists.